"""
Type annotations for cloudsearchdomain service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_cloudsearchdomain.type_defs import BlobTypeDef

    data: BlobTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from typing import IO, Any, Union

from botocore.response import StreamingBody

from .literals import ContentTypeType, QueryParserType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "BlobTypeDef",
    "BucketInfoTypeDef",
    "BucketTypeDef",
    "DocumentServiceWarningTypeDef",
    "FieldStatsTypeDef",
    "HitTypeDef",
    "HitsTypeDef",
    "ResponseMetadataTypeDef",
    "SearchRequestTypeDef",
    "SearchResponseTypeDef",
    "SearchStatusTypeDef",
    "SuggestModelTypeDef",
    "SuggestRequestTypeDef",
    "SuggestResponseTypeDef",
    "SuggestStatusTypeDef",
    "SuggestionMatchTypeDef",
    "UploadDocumentsRequestTypeDef",
    "UploadDocumentsResponseTypeDef",
)

BlobTypeDef = Union[str, bytes, IO[Any], StreamingBody]


class BucketTypeDef(TypedDict):
    value: NotRequired[str]
    count: NotRequired[int]


class DocumentServiceWarningTypeDef(TypedDict):
    message: NotRequired[str]


FieldStatsTypeDef = TypedDict(
    "FieldStatsTypeDef",
    {
        "min": NotRequired[str],
        "max": NotRequired[str],
        "count": NotRequired[int],
        "missing": NotRequired[int],
        "sum": NotRequired[float],
        "sumOfSquares": NotRequired[float],
        "mean": NotRequired[str],
        "stddev": NotRequired[float],
    },
)
HitTypeDef = TypedDict(
    "HitTypeDef",
    {
        "id": NotRequired[str],
        "fields": NotRequired[dict[str, list[str]]],
        "exprs": NotRequired[dict[str, str]],
        "highlights": NotRequired[dict[str, str]],
    },
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class SearchRequestTypeDef(TypedDict):
    query: str
    cursor: NotRequired[str]
    expr: NotRequired[str]
    facet: NotRequired[str]
    filterQuery: NotRequired[str]
    highlight: NotRequired[str]
    partial: NotRequired[bool]
    queryOptions: NotRequired[str]
    queryParser: NotRequired[QueryParserType]
    returnFields: NotRequired[str]
    size: NotRequired[int]
    sort: NotRequired[str]
    start: NotRequired[int]
    stats: NotRequired[str]


class SearchStatusTypeDef(TypedDict):
    timems: NotRequired[int]
    rid: NotRequired[str]


SuggestionMatchTypeDef = TypedDict(
    "SuggestionMatchTypeDef",
    {
        "suggestion": NotRequired[str],
        "score": NotRequired[int],
        "id": NotRequired[str],
    },
)


class SuggestRequestTypeDef(TypedDict):
    query: str
    suggester: str
    size: NotRequired[int]


class SuggestStatusTypeDef(TypedDict):
    timems: NotRequired[int]
    rid: NotRequired[str]


class UploadDocumentsRequestTypeDef(TypedDict):
    documents: BlobTypeDef
    contentType: ContentTypeType


class BucketInfoTypeDef(TypedDict):
    buckets: NotRequired[list[BucketTypeDef]]


class HitsTypeDef(TypedDict):
    found: NotRequired[int]
    start: NotRequired[int]
    cursor: NotRequired[str]
    hit: NotRequired[list[HitTypeDef]]


class UploadDocumentsResponseTypeDef(TypedDict):
    status: str
    adds: int
    deletes: int
    warnings: list[DocumentServiceWarningTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class SuggestModelTypeDef(TypedDict):
    query: NotRequired[str]
    found: NotRequired[int]
    suggestions: NotRequired[list[SuggestionMatchTypeDef]]


class SearchResponseTypeDef(TypedDict):
    status: SearchStatusTypeDef
    hits: HitsTypeDef
    facets: dict[str, BucketInfoTypeDef]
    stats: dict[str, FieldStatsTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class SuggestResponseTypeDef(TypedDict):
    status: SuggestStatusTypeDef
    suggest: SuggestModelTypeDef
    ResponseMetadata: ResponseMetadataTypeDef



"""
Type annotations for cloudsearchdomain service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_cloudsearchdomain.client import CloudSearchDomainClient

    session = Session()
    client: CloudSearchDomainClient = session.client("cloudsearchdomain")
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping
from typing import Any

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import (
    SearchRequestTypeDef,
    SearchResponseTypeDef,
    SuggestRequestTypeDef,
    SuggestResponseTypeDef,
    UploadDocumentsRequestTypeDef,
    UploadDocumentsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("CloudSearchDomainClient",)

class Exceptions(BaseClientExceptions):
    ClientError: type[BotocoreClientError]
    DocumentServiceException: type[BotocoreClientError]
    SearchException: type[BotocoreClientError]

class CloudSearchDomainClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        CloudSearchDomainClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#generate_presigned_url)
        """

    def search(self, **kwargs: Unpack[SearchRequestTypeDef]) -> SearchResponseTypeDef:
        """
        Retrieves a list of documents that match the specified search criteria.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain/client/search.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#search)
        """

    def suggest(self, **kwargs: Unpack[SuggestRequestTypeDef]) -> SuggestResponseTypeDef:
        """
        Retrieves autocomplete suggestions for a partial query string.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain/client/suggest.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#suggest)
        """

    def upload_documents(
        self, **kwargs: Unpack[UploadDocumentsRequestTypeDef]
    ) -> UploadDocumentsResponseTypeDef:
        """
        Posts a batch of documents to a search domain for indexing.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearchdomain/client/upload_documents.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/client/#upload_documents)
        """



"""
Main interface for cloudsearchdomain service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_cloudsearchdomain/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_cloudsearchdomain import (
        Client,
        CloudSearchDomainClient,
    )

    session = Session()
    client: CloudSearchDomainClient = session.client("cloudsearchdomain")
    ```
"""

from .client import CloudSearchDomainClient

Client = CloudSearchDomainClient

__all__ = ("Client", "CloudSearchDomainClient")
